/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.commons.validator;

import static org.junit.jupiter.api.Assertions.fail;

import java.io.InputStream;

import org.junit.jupiter.api.Test;

/**
 * Test ValidatorResources.
 */
public class ValidatorResourcesTest {

    /**
     * Test null Input Stream for Validator Resources.
     */
    @Test
    public void testNullInputStream() throws Exception {

        try {
            new ValidatorResources((InputStream) null);
            fail("Expected IllegalArgumentException");
        } catch (final IllegalArgumentException e) {
            // expected result
            // System.out.println("Exception: " + e);
        }

    }

}
